@@ -128,7 +128,7 @@ Uses the variable `inferior-ess-help-command' for the actual help command.
 Prompts for the object name based on the cursor location for all cases
 except the S-Plus GUI.  With S-Plus on Windows (both GUI and in an inferior
 emacs buffer) the GUI help window is used."
-  (interactive 
+  (interactive
    (if (ess-ddeclient-p)
        (list (read-string "Help on: "))
      (ess-find-help-file "Help on: ")))
@@ -397,10 +397,10 @@ Other keybindings are as follows:
   ;; section headings.
 
   (setq ess-help-sec-map (make-sparse-keymap))
-  (mapcar '(lambda (key)
-	    (define-key ess-help-sec-map (char-to-string key)
-	      'ess-skip-to-help-section))
-	    (mapcar 'car ess-help-sec-keys-alist))
+  (mapc '(lambda (key)
+	   (define-key ess-help-sec-map (char-to-string key)
+	     'ess-skip-to-help-section))
+	(mapcar 'car ess-help-sec-keys-alist))
   (define-key ess-help-sec-map "?" 'ess-describe-sec-map)
   (define-key ess-help-sec-map ">" 'end-of-buffer)
   (define-key ess-help-sec-map "<" 'beginning-of-buffer)
@@ -419,10 +419,10 @@ to see which keystrokes find which sections."
   (let ((old-point (point))
 	(case-fold-search nil))
     (goto-char (point-min))
-    (let ((the-sec (cdr (assoc last-command-char
+    (let ((the-sec (cdr (assoc last-command-event
 			       ess-help-sec-keys-alist))))
       (if (not the-sec) (error "Invalid section key: %c"
-			       last-command-char)
+			       last-command-event)
 	(if (re-search-forward (concat "^" the-sec) nil t) nil
 	    (message "No %s section in this help. Sorry." the-sec)
 	    (goto-char old-point))))))
@@ -465,11 +465,11 @@ to see which keystrokes find which sections."
 
 Keystroke    Section
 ---------    -------\n")
-      (mapcar '(lambda (cs) (insert "	 "
-				    (car cs)
-				    "	   "
-				    (cdr cs) "\n"))
-	      keys-alist)
+      (mapc '(lambda (cs) (insert "    "
+				  (car cs)
+				  "      "
+				  (cdr cs) "\n"))
+	    keys-alist)
       (insert "\nFull list of key definitions:\n"
 	      (substitute-command-keys
 	       "\\{ess-help-sec-map}")))))
@@ -498,10 +498,12 @@ Stata or XLispStat for additional information."
 	(string-match "XLS" ess-language)
 	(string-match "STA" ess-language)
 	(string-match "SAS" ess-language)))
-      (let* ((help-files-list (or (ess-get-help-files-list)
-				  (mapcar 'list
-					  (ess-get-object-list
-					   ess-current-process-name))))
+      (let* ((help-files-list
+	      (ess-uniq-list (append (ess-get-help-files-list)
+				   (ess-get-help-aliases-list)
+				   (mapcar 'list
+					   (ess-get-object-list
+					    ess-current-process-name)))))
 	     (default (ess-read-helpobj-name-default help-files-list))
 	     (prompt-string (if default
 				(format "%s(default %s) " p-string default)
@@ -526,6 +528,20 @@ Stata or XLispStat for additional information."
 			 (mapcar '(lambda (str) (concat str "/.Help"))
 				 (ess-search-list))))))
 
+(defun ess-get-help-aliases-list ()
+  "Return a list of aliases which have help available."
+  (ess-uniq-list
+   (mapcar 'list
+	   (apply 'append
+		  (mapcar '(lambda (a-file)
+			     (if (file-exists-p a-file)
+				 (ess-get-words-from-vector
+				  (format
+				   "names(.readRDS(\"%s\"))\n" a-file))))
+			  (mapcar '(lambda (str) (concat str "/help/aliases.rds"))
+				  (ess-get-words-from-vector
+				   "searchpaths()\n")))))))
+
 (defun ess-nuke-help-bs ()
   "Remove ASCII underlining and overstriking performed by ^H codes."
   ;; This function is a modification of nuke-nroff-bs in man.el from the
@@ -589,8 +605,8 @@ Stata or XLispStat for additional information."
 	   'ess-keep-dump-files
 	   'ess-source-directory)
      nil
-     (lambda () 
-       ;;(goto-char (point-max)) 
+     (lambda ()
+       ;;(goto-char (point-max))
        (rfc822-goto-eoh)
        (forward-line 1)
        (insert "\nThis bug report will be sent to the ESS bugs email list\n")
