@@ -460,7 +460,9 @@ sending `inferior-ess-language-start' to S-Plus.")
 
 (autoload 'ess-roxy-mode "ess-roxy"
   "Insert and edit Roxygen tags for function definitions." t)
-(add-hook 'ess-mode-hook 'ess-roxy-mode)
+;; if ever ess-roxy works for non- R ess modes, we will have
+;; (add-hook 'ess-mode-hook 'ess-roxy-mode)
+(add-hook 'R-mode-hook 'ess-roxy-mode)
 
 
 ;;; On a PC, the default is S+6.
